#
# spec file for package checkpolicy
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libsepol_ver 2.5
Name:           checkpolicy
Version:        2.5
Release:        3.11
Summary:        SELinux policy compiler
License:        GPL-2.0+
Group:          Productivity/Security
Url:            https://github.com/SELinuxProject/selinux
Source:         https://raw.githubusercontent.com/wiki/SELinuxProject/selinux/files/releases/20160223/%{name}-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  flex-old
BuildRequires:  libselinux-devel
BuildRequires:  libsepol-devel-static >= %{libsepol_ver}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Security-enhanced Linux is a feature of the Linux(R) kernel and a
number of utilities with enhanced security functionality designed to
add mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These architectural
components provide general support for the enforcement of many kinds of
mandatory access control policies, including those based on the
concepts of Type Enforcement(R), Role-based Access Control, and
Multi-level Security.

This package contains checkpolicy, the SELinux policy compiler. Only
required for building policies.

%prep
%setup -q

%build
make %{?_smp_mflags} clean
make LIBDIR="%{_libdir}" CFLAGS="%{optflags}" %{?_smp_mflags}
cd test
make LIBDIR="%{_libdir}" CFLAGS="%{optflags}" %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_bindir}
make LIBDIR="%{_libdir}" DESTDIR=%{buildroot} install
install test/dismod %{buildroot}%{_bindir}/sedismod
install test/dispol %{buildroot}%{_bindir}/sedispol

%files
%defattr(-,root,root)
%doc COPYING ChangeLog
%{_bindir}/checkpolicy
%{_bindir}/checkmodule
%{_bindir}/sedismod
%{_bindir}/sedispol
%{_mandir}/man8/checkmodule.8%{ext_man}
%{_mandir}/man8/checkpolicy.8%{ext_man}

%changelog
* Thu Jul 14 2016 jsegitz@novell.com
- Without bug number no submit to SLE 12 SP2 is possible, so to make
  sle-changelog-checker happy: bsc#988977
* Fri Jul  8 2016 i@marguerite.su
- update version 2.5
  * Add neverallow support for ioctl extended permissions
  * fix double free on name-based type transitions
  * switch operations to extended perms
  * policy_define.c: fix compiler warnings
  * Remove uses of -Wno-return-type
  * Fix -Wreturn-type issues
  * dispol: display operations as ranges
  * dispol: Extend to display operations
  * Add support for ioctl command whitelisting
  * Add option to write CIL policy
  * Add device tree ocontext nodes to Xen policy
  * Widen Xen IOMEM context entries
  * Expand allowed character set in paths
  * Fix precedence between number and filesystem tokens
  * dispol/dismod fgets function warnings fix
- changes in 2.4
  * Fix bugs found by hardened gcc flags
  * Add missing semicolon in cond_else parser rule
  * Clear errno before call to strtol(3)
  * Global C++11 compatibility
  * Allow libsepol C++ static library on device
* Sun May 18 2014 crrodriguez@opensuse.org
- version 2.3
  * Report source file and line information for neverallow failures.
  * Prevent incompatible option combinations for checkmodule.
  * Drop -lselinux from LDLIBS for test programs; not used.
  * Add debug feature to display constraints/validatetrans from Richard Haines.
* Thu Oct 31 2013 p.drouand@gmail.com
- Update to version 2.2
  * Fix hyphen usage in man pages
  * handle-unknown / -U required argument fix
  * Support overriding Makefile PATH and LIBDIR
  * Support space and : in filenames
- Remove checkpolicy-rhat.patch; fixed on upstream
* Thu Jun 27 2013 vcizek@suse.com
- change the source url to the official 2.1.12 release tarball
* Fri Mar 29 2013 vcizek@suse.com
- update to 2.1.12
  * Fix errors found by coverity
  * implement default type policy syntax
  * Free allocated memory when clean up / exit.
- changes in checkpolicy-rhat.patch:
  * original hunk was merged upstream
  * space should be allowed for file trans names
* Wed Jan 30 2013 vcizek@suse.com
- update to 2.1.11
  * fd leak reading policy
  * check return code on ebitmap_set_bit
  * sepolgen: We need to support files that have a + in them
  * implement new default labeling behaviors for usr, role, range
* Wed Jul 25 2012 meissner@suse.com
- updated to 2.1.8
  - various fixes
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu Feb 25 2010 prusnak@suse.cz
- updated to 2.0.21
  * Add support for building Xen policies from Paul Nuzzi.
  * Add long options to checkpolicy and checkmodule by Guido
    Trentalancia <guido@trentalancia.com>
* Tue Jun 23 2009 prusnak@suse.cz
- require libsepol-devel-static
* Wed May 27 2009 prusnak@suse.cz
- updated to 2.0.19
  * fix alias field in module format, caused by boundary format change
    from Caleb Case
  * properly escape regex symbols in the lexer from Stephen Smalley
  * add bounds support from KaiGai Kohei
* Mon Oct 20 2008 prusnak@suse.cz
- use flex-old for building (using flex does not build refpolicy)
* Tue Jul 15 2008 prusnak@suse.cz
- initial version 2.0.16
  * based on Fedora package by Dan Walsh <dwalsh@redhat.com>
